@@ -1,6 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::Cell;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = qv('v0.38.12');
+use version; our $VERSION = qv('v0.38.14');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::XLSX::Reader::LibXML::Cell-$VERSION";
 
 $| = 1;
@@ -133,7 +133,7 @@ has cell_hyperlink =>(
 		predicate	=> 'has_hyperlink',
 	);
 
-has is_hidden =>(
+has cell_hidden =>(
 		isa			=> Enum[qw( sheet column row 0 )],
 		reader		=> 'is_hidden',
 		default		=> 0,
